@@ -71,7 +71,7 @@ class WeatherLib : public QObject
 	private:
 		Data* findData(const QString &stationID);
 		void clearData(Data *d);
-		void getData(Data *d);
+		void getData(Data *d, bool force = false);
 		void processData(const QString &metar, Data *d);
 
 		StationDatabase *m_StationDb;
